@@ -1,6 +1,6 @@
 package Net::Riak::Bucket;
 BEGIN {
-  $Net::Riak::Bucket::VERSION = '0.01';
+  $Net::Riak::Bucket::VERSION = '0.02';
 }
 
 # ABSTRACT: Access and change information about a Riak bucket
@@ -16,7 +16,7 @@ has name => (
 );
 has client => (
     is       => 'ro',
-    isa      => 'Net::Riak',
+    isa      => 'Net::Riak::Client',
     required => 1
 );
 has content_type => (
@@ -24,7 +24,6 @@ has content_type => (
     isa     => 'Str',
     default => 'application/json'
 );
-
 has r => (
     is      => 'rw',
     isa     => 'Int',
@@ -130,7 +129,7 @@ sub new_object {
         key    => $key,
         data   => $data,
         bucket => $self,
-        client => $self->client
+        client => $self->client,
     );
     $object;
 }
@@ -147,7 +146,7 @@ Net::Riak::Bucket - Access and change information about a Riak bucket
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
